#include "EncryptDecrypt.h"
#include "Help.h"
#include <iostream>
#include <cstdlib>
#include <filesystem>

int main(int argc, char* argv[]) {
    // Checks if at least one argument is passed
    if (argc < 2) {
        std::cerr << "Error: Missing arguments. Use '--help' or '-h' for usage instructions.\n";
        return 1;  // Exit with error message.
    }

    std::string option = argv[1];
    // If user asks for help, display usage instructions.
    if (option == "--help" || option == "-h") {
        displayHelp();
        return 0;  // Exit successfully after displaying help
    }
// Check for the minimum number of arguments for actual operation
    if (argc < 5) {
        std::cerr << "Error: Insufficient arguments. Use '--help' or '-h' for usage instructions.\n";
        return 1;
    }
    // Extract command-line arguments
    std::string operation = argv[1];
    std::string algorithm = argv[2];
    std::string fileName = argv[3];
    std::string key = argv[4];
    
    // Reads content from the input file
    std::string content = readFile(fileName);
    if (content.empty()) {
        return 1;  // Exit if file could not be read
    }

    std::string result;

    // Process based on the selected algorithm
    if (algorithm == "caesar") {
        int intKey = std::stoi(key);  // Convert Caesar key to integer
        if (operation == "encrypt") {
            result = caesarEncrypt(content, intKey);
        } else if (operation == "decrypt") {
            result = caesarDecrypt(content, intKey);
        } else {
            std::cerr << "Invalid operation: " << operation << "\n";
            return 1;
        }
    } else if (algorithm == "xor") {
        if (key.length() != 1) {
            std::cerr << "Error: XOR key must be a single character.\n";
            return 1;
        }
        char charKey = key[0];  // Use single character as XOR key
        result = xorEncryptDecrypt(content, charKey);
    } else if (algorithm == "vigenere") {
        if (operation == "encrypt") {
            result = vigenereEncrypt(content, key);
        } else if (operation == "decrypt") {
            result = vigenereDecrypt(content, key);
        } else {
            std::cerr << "Invalid operation: " << operation << "\n";
            return 1;
        }
    } else {
        std::cerr << "Invalid algorithm: " << algorithm << "\n";
        return 1;
    }

    // Overwrite the original file with the result (optional/temporary)
    writeFile(fileName, result);
    std::cout << "Operation completed successfully!\n";

    // Pause the terminal
  //  std::cout << "Press Enter to exit...";
  //  std::cin.ignore();
  //  std::cin.get();
  

  // testing to write to a brand new file
   //std::filesystem::path inputPath(argv[3]);
  // std::string stem = inputPath.stem().string();
  // std::string extension = inputPath.extension().string();
  // std::string outputFile = stem + "_" + operation + extension;
  
  // Write the result to the new file.
  // writeFile(outputFile, result);
  
  //std::cout << "Output written to: " << outputFile << std::endl;

    return 0;
}
